{ AwkZip32 demonstration program
  By Carl Bunton

  This sample source is being kept to a minimum to demonstrate
  the true simplicity of using the AwkZip32 component.  It was
  our goal to keep TAwkZip as low level as possible to retain
  utmost flexibility for the programmer.

  The steps in this sample to view and extract a file from
  a zipped file are as follows:

  1. TForm1.Open1Click : Calls the Activate Method.

  2. TForm1.AwkZip1Activate: Clears the list & defines the filename.

	3.	TForm1.AwkZip1Read : After the call to the Activate method,
     the 'OnRead' event is activated with each file found within
     a compressed archive returning detailed information on that
     specific file.  In this demonstration, we just add the information
     to a list.

	4. TForm1.AwkZip1Totals : Returns totals information after all
     files have been read.

  5. TForm1.ListView1DblClick : Hilite the filename in the list
     and double click.  The ListView control returns the index of
     the file clicked.  In this demo program, we use the index number
     to extract the desired file.	}


unit Readzip;

interface

uses
  SysUtils, WinTypes, WinProcs, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Menus, Buttons, ComCtrls, ExtCtrls, AwkZip,
  Unzip;

type
	TForm1 = class(TForm)

    	OpenDialog1	: TOpenDialog;
  	MainMenu1	: TMainMenu;
    	File1			: TMenuItem;
    	Open1			: TMenuItem;
    	Exit1			: TMenuItem;
    	Extract2		: TMenuItem;
    	All1			: TMenuItem;
    	Hilited1		: TMenuItem;
    	Hilited2		: TMenuItem;

    	PopupMenu1	: TPopupMenu;
    	Open2			: TMenuItem;
    	Exit2			: TMenuItem;
    	Extract1		: TMenuItem;

    	ListView1	: TListView;
    	ListView2	: TListView;
    	Memo1			: TMemo;
    	Label1		: TLabel;
    	Label2		: TLabel;
    	lblFileSpec	: TLabel;

    	AwkZip1		: TAwkZip;
    Label3: TLabel;


    	procedure Open1Click(Sender: TObject);
    	procedure Exit1Click(Sender: TObject);

		procedure AwkZip1Totals		(var Sender: TObject; NumFiles: Longint);
    	procedure AwkZip1Read		(var Sender: TObject);
    	procedure AwkZip1Activate	(var Sender: TObject);
    	procedure AwkZip1ExtractErr(var Sender: TObject; Filename,
      		ErrStr: string; ErrNum: TAwkError; var Action: boolean);

    	procedure ListView1ColumnClick(Sender: TObject; Column: TListColumn);
    	procedure ListView1Changing(Sender: TObject; Item: TListItem;
        	Change: TItemChange; var AllowChange: Boolean);

    	procedure All1Click(Sender: TObject);
    	procedure Hilited1Click(Sender: TObject);
    	procedure Hilited2Click(Sender: TObject);
    procedure FormActivate(Sender: TObject);
  private
  public
  end;


var
	Form1: TForm1;



implementation


{$R *.DFM}

{ -------------------------------------------------------------- }
procedure TForm1.Open1Click(Sender: TObject);
var
	r: TAwkError;
begin
  {activate the zipfile read}
	r := AwkZip1.Activate;

	{check if any error occured}
  if r > None
  then MessageDlg('Error: ' + ErrCodeStr, mtInformation, [mbOK], 0);
end;
{ -------------------------------------------------------------- }
procedure TForm1.Exit1Click(Sender: TObject);
begin
	{close the demo program}
	close;
end;
{ --------------------------------------------------------------
  	 ==== the 3 events: OnActivate/OnRead/OnTotals ====
  -------------------------------------------------------------- }
// activate the TAwkZip component
procedure TForm1.AwkZip1Activate(var Sender: TObject);
begin
	if OpenDialog1.Execute then
 	begin
  	ListView1.items.Clear;
     Memo1.Text :='';
     Form1.Caption := OpenDialog1.FileName;
     AwkZip1.FileName  := OpenDialog1.FileName;	{assign filename TAwkZip component}
  end;
end;
{ -------------------------------------------------------------- }
// fill listbox with detailed compressed file info
procedure TForm1.AwkZip1Read(var Sender: TObject);
var
	NewItem : TListItem;
begin
	if AwkZip1.UnpackedSize > 0
  then begin
  	NewItem := ListView1.Items.Add;
  	NewItem.Caption := AwkZip1.CompressedFilename;						{filename}
     NewItem.SubItems.Add('');

  	NewItem.SubItems.Add(FormatDateTime('mm-dd-yy',AwkZip1.Date)); {Date}
     NewItem.SubItems.Add(FormatDateTime('hh:mm',AwkZip1.Date));    {Time}
     NewItem.SubItems.Add(IntToStr(AwkZip1.PackedSize));            {PackedSize}
     NewItem.SubItems.Add(IntToStr(AwkZip1.UnpackedSize));          {UnpackedSize}
     NewItem.SubItems.Add(IntToStr(AwkZip1.Ratio) + '%');           {Ratio}
     NewItem.SubItems.Add(AwkZip1.sCompressionMethod);              {(string) method}
     {NewItem.SubItems.Add(IntToStr(AwkZip1.wCompressionMethod));}  {(word) method}
     NewItem.SubItems.Add(AwkZip1.Directory);                       {extract dir}
     NewItem.SubItems.Add(AwkZip1.FileComment);							{file comment}
   end;
end;
{ -------------------------------------------------------------- }
// display the totals
procedure TForm1.AwkZip1Totals(var Sender: TObject; NumFiles: Longint);
var
	NewItem : TListItem;
begin
	ListView2.items.Clear;
  NewItem := ListView2.Items.Add;
  NewItem.SubItems.Add(inttostr(AwkZip1.PackedSize));      {PackedSize}
  NewItem.SubItems.Add(inttostr(AwkZip1.UnpackedSize));    {UnpackedSize}
  NewItem.SubItems.Add(IntToStr(AwkZip1.Ratio) + '%');     {ratio}
  Memo1.Text := AwkZip1.ZipComment;								{archive comment}
end;
{ ============================================================== }
// click the lists headings
procedure TForm1.ListView1ColumnClick(Sender: TObject;
  Column: TListColumn);
begin
  MessageDlg(IntToStr(Column.Index), mtWarning, [mbOk], 0);
  case Column.Index of
     1:	;				{Filename}
  	2:	;				{Date}
     3: ;           {Time}
     4: ;           {UnCompressed}
     5: ;           {Compressed}
     6: ;           {Ratio}
     7: ;           {Method}
		8: ;				{Extract To (dir)}
     9: ;           {FileComment}
  end;
end;
{ -------------------------------------------------------------- }
// ExtractErr returns error triggered during decompression.. process accordingly.
procedure TForm1.AwkZip1ExtractErr(var Sender: TObject; Filename,
  ErrStr: string; ErrNum: TAwkError; var Action: boolean);
begin
	if ErrNum = Fexists
  then begin
     if MessageDlg(Filename + '...exists, Overwrite?',
        mtWarning, [mbYes, mbNo], 0) = mrYes
     then
     	Action := True;	{go ahead and overwrite the file}
  end else

   if ErrNum > None
   then
   	MessageDlg(Filename + #13 + 'Error: ' + IntToStr(Ord(ErrNum)) + #13 + ErrCodeStr, mtInformation, [mbOK], 0);
end;
{ -------------------------------------------------------------- }
procedure TForm1.ListView1Changing(Sender: TObject; Item: TListItem;
  Change: TItemChange; var AllowChange: Boolean);
begin
	;
end;
{ ------- Extract single file using List Index parameter ------- }
procedure TForm1.Hilited1Click(Sender: TObject);
var
	Index : word;
begin
	with ListView1 do
  	Index := Items.IndexOf(Selected) + 1;	{add one to match AwkZip}

  if Index > 0
  then AwkZip1.Extract('', Index)				{ using the files index }
	else MessageDlg('Select a file to extract.',mtInformation,[mbOK],0);
end;
{ ------- Extract single file using filename parameter --------- }
procedure TForm1.Hilited2Click(Sender: TObject);
begin
	if ListView1.Items.Count > 0
  then if ListView1.Selected <> nil
  then AwkZip1.Extract(ListView1.Selected.Caption,0)   { using filename }
	else MessageDlg('Select a file to extract.',mtInformation,[mbOK],0);
end;
{ ------------ Extract using wildcard chars -------------------- }
procedure TForm1.All1Click(Sender: TObject);
begin
	AwkZip1.Extract('*.*', 0);				{ using wildcards }
	{AwkZip1.Extract('*.???', 0);}  		{ using wildcards }
	{AwkZip1.Extract('*.e?e', 0);}  		{ using wildcards }
end;

procedure TForm1.FormActivate(Sender: TObject);
begin
	lblFileSpec.Caption := AwkZip1.FileSpec;
end;

end.

